Updating the font
=================

raw.sfd is a fontforge file, raw.woff is generated from this.  We should
automate this but haven't, but essentially fontforge should be able to output
the .woff from the .sfd with some scripting
